==> emacs-auctex-11.88-2.tar.xz: usr/share/emacs/site-lisp/preview-latex.el <==
;;; preview-latex.el --- automatically extracted autoloads
;;
;;; Code:


;;;### (autoloads nil "preview" "preview.el" (21885 33555 86117 200000))
;;; Generated autoloads from preview.el

(autoload 'preview-install-styles "preview" "\
Installs the TeX style files into a permanent location.
This must be in the TeX search path.  If FORCE-OVERWRITE is greater
than 1, files will get overwritten without query, if it is less
than 1 or nil, the operation will fail.  The default of 1 for interactive
use will query.

Similarly FORCE-SAVE can be used for saving
`preview-TeX-style-dir' to record the fact that the uninstalled
files are no longer needed in the search path.

\(fn DIR &optional FORCE-OVERWRITE FORCE-SAVE)" t nil)

(autoload 'LaTeX-preview-setup "preview" "\
Hook function for embedding the preview package into AUCTeX.
This is called by `LaTeX-mode-hook' and changes AUCTeX variables
to add the preview functionality.

\(fn)" nil nil)
 (add-hook 'LaTeX-mode-hook #'LaTeX-preview-setup)

(autoload 'preview-report-bug "preview" "\
Report a bug in the preview-latex package.

\(fn)" t nil)

;;;***

(provide 'preview-latex)
;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8
;; End:
;;; preview-latex.el ends here

(defvar preview-lispdir (expand-file-name "auctex" (file-name-directory load-file-name)))
(add-to-list 'load-path preview-lispdir)
(defvar preview-datadir (expand-file-name "auctex" (file-name-directory load-file-name)))

==> emacs-auctex-13.2-1.tar.xz: usr/share/emacs/site-lisp/preview-latex.el <==
;;; preview-latex.el --- automatically extracted autoloads  -*- lexical-binding: t -*-
;;
;;; Code:


;;;### (autoloads nil "preview" "preview.el" (25679 44930 923593
;;;;;;  100000))
;;; Generated autoloads from preview.el

(autoload 'desktop-buffer-preview "preview" "\
Hook function for restoring persistent previews into a buffer.

\(fn FILE-NAME BUFFER-NAME MISC)" nil nil)

(add-to-list 'desktop-buffer-mode-handlers '(latex-mode . desktop-buffer-preview))

(autoload 'preview-install-styles "preview" "\
Installs the TeX style files into a permanent location.
This must be in the TeX search path.  If FORCE-OVERWRITE is greater
than 1, files will get overwritten without query, if it is less
than 1 or nil, the operation will fail.  The default of 1 for interactive
use will query.

Similarly FORCE-SAVE can be used for saving
`preview-TeX-style-dir' to record the fact that the uninstalled
files are no longer needed in the search path.

\(fn DIR &optional FORCE-OVERWRITE FORCE-SAVE)" t nil)

(autoload 'LaTeX-preview-setup "preview" "\
Hook function for embedding the preview package into AUCTeX.
This is called by `LaTeX-mode-hook' and changes AUCTeX variables
to add the preview functionality." nil nil)

(autoload 'preview-report-bug "preview" "\
Report a bug in the preview-latex package." t nil)

(register-definition-prefixes "preview" '("TeX-" "desktop-buffer-preview-misc-data" "preview-"))

;;;***

(provide 'preview-latex)
;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; coding: utf-8
;; End:
;;; preview-latex.el ends here
